from survdata import datasets
import sklearn.utils as skut

def test_seer_dataset():
    X, y = datasets.load_seer_dataset()
    skut.check_X_y(X, y, dtype=None)
    
def test_load_nhanes_dataset():
    X, y = datasets.load_nhanes_dataset()
    skut.check_X_y(X, y, dtype=None, force_all_finite='allow-nan')
    
def test_load_support_dataset():
    X, y = datasets.load_support_dataset()
    skut.check_X_y(X, y, dtype=None)
    
def test_load_aids_dataset():
    X, y = datasets.load_aids_dataset()
    skut.check_X_y(X, y, dtype=None)

def test_load_veterans_dataset():
    X, y = datasets.load_veterans_dataset()
    skut.check_X_y(X, y, dtype=None)
    
def test_load_whas500_dataset():
    X, y = datasets.load_whas500_dataset()
    skut.check_X_y(X, y, dtype=None)

def test_load_flchain_dataset():
    X, y = datasets.load_flchain_dataset()
    skut.check_X_y(X, y, dtype=None, force_all_finite='allow-nan')
    
def test_load_gbsg2_dataset():
    X, y = datasets.load_gbsg2_dataset()
    skut.check_X_y(X, y, dtype=None)

def test_load_metabric_dataset():
    X, y = datasets.load_metabric_dataset()
    skut.check_X_y(X, y, dtype=None)


from setuptools import setup, find_packages

setup(
    name = 'survival-datasets', 
    version = '0.1.1',
    description = 'Data loader for common datasets in Survival Analysis.',
    packages = find_packages(where="src"),
    package_dir={"": "src"},
    include_package_data=True,
    author = 'Christian Marius Lillelund',
    author_email = 'chr1000@gmail.com',
    
    long_description = open('README.md').read(),
    long_description_content_type = "text/markdown",

    url='https://github.com/thecml/survival-datasets',

    classifiers  = [
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 3.9',
        "License :: OSI Approved :: MIT License",
        'Intended Audience :: Developers',
        'Intended Audience :: Other Audience',
        'Intended Audience :: Science/Research',
        'Intended Audience :: Education',
        'Topic :: Scientific/Engineering :: Artificial Intelligence',
        'Operating System :: OS Independent',
    ],
    
    install_requires = [
        'scikit-survival ~= 0.17.2',
        'pandas ~= 1.4.3',
        'numpy ~= 1.22.4',
        'shap ~= 0.41.0',
        'pyarrow ~= 11.0.0',
    ],
    
    keywords = ['Survival Analysis', 'Datasets'],
    
)



__author__='Christian Marius Lillelund'
__author_email__='chr1000@gmail.com'

import numpy as np
import pandas as pd
import shap
from sksurv import datasets

import pkg_resources

resource_package = __name__

def convert_to_structured(T, E):
    default_dtypes = {"names": ("event", "time"), "formats": ("bool", "f8")}
    concat = list(zip(E, T))
    return np.array(concat, dtype=default_dtypes)

def load_seer_dataset():
    resource = pkg_resources.resource_stream(resource_package, 'seer.csv')    
    data = pd.read_csv(resource)

    outcomes = data.copy()
    outcomes['event'] =  data['Status']
    outcomes['time'] = data['Survival Months']
    outcomes = outcomes[['event', 'time']]
    outcomes.loc[outcomes['event'] == 'Alive', ['event']] = 0
    outcomes.loc[outcomes['event'] == 'Dead', ['event']] = 1
    
    data = data.drop(['Status', "Survival Months"], axis=1)
    
    X = pd.DataFrame(data)
    y = convert_to_structured(outcomes['time'], outcomes['event'])
    return (X, y)

def load_nhanes_dataset():    
    nhanes_X, nhanes_y = shap.datasets.nhanesi()
    X = pd.DataFrame(nhanes_X)
    event = np.array([True if x > 0 else False for x in nhanes_y])
    time = np.array(abs(nhanes_y))
    y = convert_to_structured(time, event)
    return (X, y)

def load_support_dataset():
    resource = pkg_resources.resource_stream(resource_package, 'support.feather')    
    data = pd.read_feather(resource)

    outcomes = data.copy()
    outcomes['event'] =  data['event']
    outcomes['time'] = data['duration']
    outcomes = outcomes[['event', 'time']]
    
    feats =  ['x0', 'x1', 'x2', 'x3', 'x4', 'x5', 'x6',
              'x7', 'x8', 'x9', 'x10', 'x11', 'x12', 'x13']
    
    X = pd.DataFrame(data[feats])
    y = convert_to_structured(outcomes['time'], outcomes['event'])
    return (X, y)

def load_aids_dataset():
    X, y = datasets.load_aids()
    X = pd.DataFrame(X) 
    y = convert_to_structured(y['time'], y['censor'])
    return (X, y)

def load_veterans_dataset():
    X, y = datasets.load_veterans_lung_cancer()
    X = pd.DataFrame(X) 
    y = convert_to_structured(y['Survival_in_days'], y['Status'])
    return (X, y)

def load_whas500_dataset():
    X, y = datasets.load_whas500()
    X = pd.DataFrame(X) 
    y = convert_to_structured(y['lenfol'], y['fstat'])
    return (X, y)

def load_flchain_dataset():
    X, y = datasets.load_flchain()
    X = pd.DataFrame(X) 
    y = convert_to_structured(y['futime'], y['death'])
    return (X, y)

def load_gbsg2_dataset():
    X, y = datasets.load_gbsg2()
    X = pd.DataFrame(X) 
    y = convert_to_structured(y['time'], y['cens'])
    return (X, y)

def load_metabric_dataset():
    resource = pkg_resources.resource_stream(resource_package, 'metabric.feather')
    data = pd.read_feather(resource)

    outcomes = data.copy()
    outcomes['event'] =  data['event']
    outcomes['time'] = data['duration']
    outcomes = outcomes[['event', 'time']]

    num_feats =  ['x0', 'x1', 'x2', 'x3', 'x8'] \
                    + ['x4', 'x5', 'x6', 'x7']

    X = pd.DataFrame(data[num_feats])
    y = convert_to_structured(outcomes['time'], outcomes['event'])
    return (X, y)